diff src/regex.h @ 89483:2f877ed80fa6

*** empty log message ***
author Kenichi Handa <handa@m17n.org>
date Mon, 08 Sep 2003 12:53:41 +0000
parents 375f2633d815 e2cc0f05e825
children 51677cb10ced
line wrap: on
line diff
--- a/src/regex.h	Mon Sep 08 11:56:09 2003 +0000
+++ b/src/regex.h	Mon Sep 08 12:53:41 2003 +0000
@@ -391,9 +391,15 @@
   unsigned not_eol : 1;
 
 #ifdef emacs
-  /* If true, multi-byte form in the `buffer' should be recognized as a
-     multibyte character. */
+  /* If true, multi-byte form in the regexp pattern should be
+     recognized as a multibyte character.  When the pattern is
+     compiled, this is set to the same value as target_multibyte
+     below.  */
   unsigned multibyte : 1;
+
+  /* If true, multi-byte form in the target of match should be
+     recognized as a multibyte character.  */
+  unsigned target_multibyte : 1;
 #endif
 
 /* [[[end pattern_buffer]]] */